@@ -20,7 +20,7 @@
 from __future__ import print_function
 from lxml import etree
 
-import requests
+import requests, json
 
 DEBUG_MODE = False
 
@@ -159,12 +159,14 @@ class TargetPay(object):
         doc = etree.fromstring(req.content)
         issuers_array = []
         issuers_dict = {}
+        index = 0
 
         for issuer in doc.findall('issuer'):
             if not as_dict:
                 issuers_array.append([issuer.get('id'), issuer.text])
             else:
-                issuers_dict[issuer.get('id')] = issuer.text
+                issuers_dict[index] = {'id': issuer.get('id'), 'name': issuer.text}
+                index += 1
         return issuers_array if not as_dict else issuers_dict
 
     def ideal_payment(self, description, amount, return_url, cancel_url = None, report_url = None, bank = None, ver = 3):
